@@ -16,7 +16,13 @@ class KPKPASS_EXPORT BoardingPass : public Pass
     Q_OBJECT
     Q_PROPERTY(TransitType transitType READ transitType CONSTANT)
 public:
-    enum TransitType { Air, Boat, Bus, Train, Generic };
+    enum TransitType {
+        Air,
+        Boat,
+        Bus,
+        Train,
+        Generic
+    };
     Q_ENUM(TransitType)
 
     explicit BoardingPass(QObject *parent = nullptr);
